@@ -2,7 +2,7 @@ setMethod(
           "pfilter",
           "mif",
           function (object, params, Np,
-                    tol = 1e-17, warn = TRUE, max.fail = 0,
+                    tol = 1e-17, max.fail = 0,
                     pred.mean = FALSE,
                     pred.var = FALSE,
                     filter.mean = FALSE,
@@ -22,7 +22,6 @@ setMethod(
                     params=params,
                     Np=Np,
                     tol=tol,
-                    warn=warn,
                     max.fail=max.fail,
                     pred.mean=pred.mean,
                     pred.var=pred.var,
